@@ -55,6 +55,10 @@ sorted_classifiers: List[str] = [
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.0",
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.1",
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.2",
+    "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.3",
+    "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.4",
+    "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.5",
+    "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.6",
     "Environment :: Handhelds/PDA's",
     "Environment :: MacOS X",
     "Environment :: MacOS X :: Aqua",
@@ -123,7 +127,10 @@ sorted_classifiers: List[str] = [
     "Framework :: Django :: 4.0",
     "Framework :: Django :: 4.1",
     "Framework :: Django :: 4.2",
+    "Framework :: Django :: 5",
     "Framework :: Django :: 5.0",
+    "Framework :: Django :: 5.1",
+    "Framework :: Django :: 5.2",
     "Framework :: Django CMS",
     "Framework :: Django CMS :: 3.4",
     "Framework :: Django CMS :: 3.5",
@@ -135,6 +142,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Django CMS :: 3.11",
     "Framework :: Django CMS :: 4.0",
     "Framework :: Django CMS :: 4.1",
+    "Framework :: Django CMS :: 4.2",
     "Framework :: FastAPI",
     "Framework :: Flake8",
     "Framework :: Flask",
@@ -169,6 +177,11 @@ sorted_classifiers: List[str] = [
     "Framework :: Odoo :: 15.0",
     "Framework :: Odoo :: 16.0",
     "Framework :: Odoo :: 17.0",
+    "Framework :: Odoo :: 18.0",
+    "Framework :: OpenTelemetry",
+    "Framework :: OpenTelemetry :: Distros",
+    "Framework :: OpenTelemetry :: Exporters",
+    "Framework :: OpenTelemetry :: Instrumentations",
     "Framework :: Opps",
     "Framework :: Paste",
     "Framework :: Pelican",
@@ -274,8 +287,10 @@ sorted_classifiers: List[str] = [
     "License :: OSI Approved :: Artistic License",
     "License :: OSI Approved :: Attribution Assurance License",
     "License :: OSI Approved :: BSD License",
+    "License :: OSI Approved :: Blue Oak Model License (BlueOak-1.0.0)",
     "License :: OSI Approved :: Boost Software License 1.0 (BSL-1.0)",
     "License :: OSI Approved :: CEA CNRS Inria Logiciel Libre License, version 2.1 (CeCILL-2.1)",
+    "License :: OSI Approved :: CMU License (MIT-CMU)",
     "License :: OSI Approved :: Common Development and Distribution License 1.0 (CDDL-1.0)",
     "License :: OSI Approved :: Common Public License",
     "License :: OSI Approved :: Eclipse Public License 1.0 (EPL-1.0)",
@@ -301,17 +316,15 @@ sorted_classifiers: List[str] = [
     "License :: OSI Approved :: Historical Permission Notice and Disclaimer (HPND)",
     "License :: OSI Approved :: IBM Public License",
     "License :: OSI Approved :: ISC License (ISCL)",
-    "License :: OSI Approved :: Intel Open Source License",
-    "License :: OSI Approved :: Jabber Open Source License",
     "License :: OSI Approved :: MIT License",
     "License :: OSI Approved :: MIT No Attribution License (MIT-0)",
-    "License :: OSI Approved :: MITRE Collaborative Virtual Workspace License (CVW)",
     "License :: OSI Approved :: MirOS License (MirOS)",
     "License :: OSI Approved :: Motosoto License",
     "License :: OSI Approved :: Mozilla Public License 1.0 (MPL)",
     "License :: OSI Approved :: Mozilla Public License 1.1 (MPL 1.1)",
     "License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)",
     "License :: OSI Approved :: Mulan Permissive Software License v2 (MulanPSL-2.0)",
+    "License :: OSI Approved :: NASA Open Source Agreement v1.3 (NASA-1.3)",
     "License :: OSI Approved :: Nethack General Public License",
     "License :: OSI Approved :: Nokia Open Source License",
     "License :: OSI Approved :: Open Group Test Suite License",
@@ -323,14 +336,12 @@ sorted_classifiers: List[str] = [
     "License :: OSI Approved :: Ricoh Source Code Public License",
     "License :: OSI Approved :: SIL Open Font License 1.1 (OFL-1.1)",
     "License :: OSI Approved :: Sleepycat License",
-    "License :: OSI Approved :: Sun Industry Standards Source License (SISSL)",
     "License :: OSI Approved :: Sun Public License",
     "License :: OSI Approved :: The Unlicense (Unlicense)",
     "License :: OSI Approved :: Universal Permissive License (UPL)",
     "License :: OSI Approved :: University of Illinois/NCSA Open Source License",
     "License :: OSI Approved :: Vovida Software License 1.0",
     "License :: OSI Approved :: W3C License",
-    "License :: OSI Approved :: X.Net License",
     "License :: OSI Approved :: Zero-Clause BSD (0BSD)",
     "License :: OSI Approved :: Zope Public License",
     "License :: OSI Approved :: zlib/libpng License",
@@ -345,6 +356,7 @@ sorted_classifiers: List[str] = [
     "Natural Language :: Bulgarian",
     "Natural Language :: Cantonese",
     "Natural Language :: Catalan",
+    "Natural Language :: Catalan (Valencian)",
     "Natural Language :: Chinese (Simplified)",
     "Natural Language :: Chinese (Traditional)",
     "Natural Language :: Croatian",
@@ -356,6 +368,7 @@ sorted_classifiers: List[str] = [
     "Natural Language :: Finnish",
     "Natural Language :: French",
     "Natural Language :: Galician",
+    "Natural Language :: Georgian",
     "Natural Language :: German",
     "Natural Language :: Greek",
     "Natural Language :: Hebrew",
@@ -509,6 +522,7 @@ sorted_classifiers: List[str] = [
     "Programming Language :: Python :: 3.11",
     "Programming Language :: Python :: 3.12",
     "Programming Language :: Python :: 3.13",
+    "Programming Language :: Python :: 3.14",
     "Programming Language :: Python :: Implementation",
     "Programming Language :: Python :: Implementation :: CPython",
     "Programming Language :: Python :: Implementation :: IronPython",
@@ -718,6 +732,7 @@ sorted_classifiers: List[str] = [
     "Topic :: Scientific/Engineering :: Medical Science Apps.",
     "Topic :: Scientific/Engineering :: Oceanography",
     "Topic :: Scientific/Engineering :: Physics",
+    "Topic :: Scientific/Engineering :: Quantum Computing",
     "Topic :: Scientific/Engineering :: Visualization",
     "Topic :: Security",
     "Topic :: Security :: Cryptography",
@@ -858,6 +873,11 @@ classifiers: Set[str] = set(sorted_classifiers)
 # A mapping from the deprecated classifier name to a list of zero or more valid
 # classifiers that should replace it
 deprecated_classifiers: Dict[str, List[str]] = {
+    "License :: OSI Approved :: Intel Open Source License": [],
+    "License :: OSI Approved :: Jabber Open Source License": [],
+    "License :: OSI Approved :: MITRE Collaborative Virtual Workspace License (CVW)": [],
+    "License :: OSI Approved :: Sun Industry Standards Source License (SISSL)": [],
+    "License :: OSI Approved :: X.Net License": [],
     "Natural Language :: Ukranian": ["Natural Language :: Ukrainian"],
     "Topic :: Communications :: Chat :: AOL Instant Messenger": [],
 }
